==> 0.6.5-beta.tar.gz: android/src/androidTest/java/com/quickblox/quickblox_sdk/auth/AuthTest.java <==
package com.quickblox.quickblox_sdk.auth;

import android.text.TextUtils;

import androidx.test.internal.runner.junit4.AndroidJUnit4ClassRunner;

import com.quickblox.auth.QBAuth;
import com.quickblox.auth.session.QBSession;
import com.quickblox.auth.session.QBSessionManager;
import com.quickblox.core.exception.QBResponseException;
import com.quickblox.quickblox_sdk.BaseTest;
import com.quickblox.quickblox_sdk.utils.DateUtil;
import com.quickblox.users.QBUsers;
import com.quickblox.users.model.QBUser;

import org.junit.Test;
import org.junit.runner.RunWith;

import java.util.Date;

import static org.junit.Assert.assertNotEquals;

@RunWith(AndroidJUnit4ClassRunner.class)
public class AuthTest extends BaseTest {

    @Test
    public void setSessionTest() {
        initCredentials();
        String token = "";
        QBUser user = buildUser();

        try {
            QBSession session = QBAuth.createSession(user).perform();
            token = session.getToken();
            assertFalse(TextUtils.isEmpty(token));
        } catch (QBResponseException exception) {
            assertNull(exception);
        }

        Date generatedTokenExpirationDate = DateUtil.generateFutureDate();
        QBSessionManager.getInstance().createActiveSession(token, generatedTokenExpirationDate);
        QBSession qbSession = QBSessionManager.getInstance().getActiveSession();
        qbSession.setUserId(BaseTest.USER_ID);
        qbSession.setAppId(Integer.valueOf(BaseTest.applicationId));

        try {
            QBUsers.signIn(user).perform();
            Date loadedTokenExpirationDate = QBSessionManager.getInstance().getActiveSession().getTokenExpirationDate();

            assertNotNull(loadedTokenExpirationDate);

            assertNotEquals(generatedTokenExpirationDate, loadedTokenExpirationDate);
        } catch (QBResponseException exception) {
            assertNull(exception);
        }
    }
}

==> 0.6.6-beta.tar.gz: android/src/androidTest/java/com/quickblox/quickblox_sdk/auth/AuthTest.java <==
package com.quickblox.quickblox_sdk.auth;

import android.text.TextUtils;

import androidx.test.internal.runner.junit4.AndroidJUnit4ClassRunner;

import com.quickblox.auth.QBAuth;
import com.quickblox.auth.session.QBSession;
import com.quickblox.auth.session.QBSessionManager;
import com.quickblox.core.exception.QBResponseException;
import com.quickblox.quickblox_sdk.BaseTest;
import com.quickblox.quickblox_sdk.utils.DateUtil;
import com.quickblox.users.QBUsers;
import com.quickblox.users.model.QBUser;

import org.junit.Test;
import org.junit.runner.RunWith;

import java.util.Date;

import static org.junit.Assert.assertNotEquals;

@RunWith(AndroidJUnit4ClassRunner.class)
public class AuthTest extends BaseTest {

    @Test
    public void setSessionTest() {
        initCredentials();
        String token = "";
        QBUser user = buildUser();

        try {
            QBSession session = QBAuth.createSession(user).perform();
            token = session.getToken();
            assertFalse(TextUtils.isEmpty(token));
        } catch (QBResponseException exception) {
            assertNull(exception);
        }

        Date generatedTokenExpirationDate = DateUtil.generateFutureDate();
        QBSessionManager.getInstance().createActiveSession(token, generatedTokenExpirationDate);
        QBSession qbSession = QBSessionManager.getInstance().getActiveSession();
        qbSession.setUserId(BaseTest.USER_ID);
        qbSession.setAppId(Integer.valueOf(BaseTest.APPLICATION_ID));

        try {
            QBUsers.signIn(user).perform();
            Date loadedTokenExpirationDate = QBSessionManager.getInstance().getActiveSession().getTokenExpirationDate();

            assertNotNull(loadedTokenExpirationDate);

            assertNotEquals(generatedTokenExpirationDate, loadedTokenExpirationDate);
        } catch (QBResponseException exception) {
            assertNull(exception);
        }
    }
}
